
#define IMSEC  0x00000001
#define IMMIN  0x00000002
#define IMHOUR 0x00000004
#define IMDOM  0x00000008
#define IMDOW  0x00000010
#define IMDOY  0x00000020
#define IMMON  0x00000040
#define IMYEAR 0x00000080

#define AMRSEC  0x1111111E   /* Enable Alarm for Seconds */
#define AMRMIN  0x1111111D   /* Enable Alarm for Minutes */
#define AMRHOUR 0x1111111B   /* Enable Alarm for Hours */
#define AMRDOM  0x11111117   /* Enable Alarm for Day of Month */
#define AMRDOW  0x111111E1   /* Enable Alarm for Day of Week */
#define AMRDOY  0x111111D1   /* Enable Alarm for Day of Year */
#define AMRMON  0x111111B1   /* Enable Alarm for Month */
#define AMRYEAR 0x11111171   /* Enable Alarm for Year */

#define ILR_RTCCIF  0x01	 // Counter Increment Interrupt block generated an interrupt
#define ILR_RTCALF  0x02	 // alarm registers generated an interrupt

#define CCR_CLKEN   0x01	 // Clock Enable
#define CCR_CTCRST  0x02	 // Clock Reset

// RTC initialize
void RTCinit(void)
{

	LPC_RTC->ILR=0; /////////////////////////

  LPC_RTC->AMR = 0xFF;
  LPC_RTC->CIIR = 0;
  LPC_RTC->CCR = CCR_CTCRST;
  return;
}

//  RTCSetTime( int s,int m,int h,int dd,int mm,int yy,int dow,int doy )
void RTCSetTime( int s,int m,int h,int dd,int mm,int yy,int dow,int doy )
{
  LPC_RTC->SEC = s;
  LPC_RTC->MIN = m;
  LPC_RTC->HOUR = h;
  LPC_RTC->DOM = mm;
  LPC_RTC->DOW = dow;
  LPC_RTC->DOY = doy;
  LPC_RTC->MONTH = mm;
  LPC_RTC->YEAR = yy;
  return;
}

//  RTCSetAlarm( int s,int m,int h,int dd,int mm,int yy,int dow,int doy )
void RTCSetAlarm( int s,int m,int h,int dd,int mm,int yy,int dow,int doy )
{
  LPC_RTC->ALSEC = s;
  LPC_RTC->ALMIN = m;
  LPC_RTC->ALHOUR = h;
  LPC_RTC->ALDOM = mm;
  LPC_RTC->ALDOW = dow;
  LPC_RTC->ALDOY = doy;
  LPC_RTC->ALMON = mm;
  LPC_RTC->ALYEAR = yy;
  return;
}

void RTCSetCIIR( uint32_t ciir )
{
	LPC_RTC->CIIR = ciir;
	return;
}

void RTCSetAlarmMask( uint32_t AlarmMask )
{
  /*--- Set alarm mask ---*/
  LPC_RTC->AMR = AlarmMask;
  return;
}

//  RTCStart( int ILRType )
void RTCStart( int ILRType )
{
  LPC_RTC->ILR = ILRType;
  LPC_RTC->CCR = CCR_CLKEN;
  return;
}


